<?php

/*
 * This file is part of the Symfony package.
 *
 * (c) Fabien Potencier <fabien.potencier@symfony-project.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Symfony\Bundle\FrameworkBundle\CacheWarmer;

use Symfony\Component\HttpKernel\CacheWarmer\CacheWarmer;
use Symfony\Component\Routing\Router;

/**
 * Generates the router matcher and generator classes.
 *
 * @author Fabien Potencier <fabien.potencier@symfony-project.com>
 */
class RouterCacheWarmer extends CacheWarmer
{
    protected $router;

    /**
     * Constructor.
     *
     * @param router $router A Router instance
     */
    public function __construct(Router $router)
    {
        $this->router = $router;
    }

    /**
     * Warms up the cache.
     *
     * @param string $cacheDir The cache directory
     */
    public function warmUp($cacheDir)
    {
        // force cache generation
        $this->router->getMatcher();
        $this->router->getGenerator();
    }

    /**
     * Checks whether this warmer is optional or not.
     *
     * @return Boolean always false
     */
    public function isOptional()
    {
        return false;
    }
}
